@@ -9,7 +9,8 @@ from click.types import StringParamType
 
 from celery import concurrency
 from celery.bin.base import (COMMA_SEPARATED_LIST, LOG_LEVEL,
-                             CeleryDaemonCommand, CeleryOption)
+                             CeleryDaemonCommand, CeleryOption,
+                             handle_preload_options)
 from celery.platforms import (EX_FAILURE, EX_OK, detached,
                               maybe_drop_privileges)
 from celery.utils.log import get_logger
@@ -94,6 +95,11 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
            executable=None, hostname=None):
     """Detach program by argv."""
     fake = 1 if C_FAKEFORK else fake
+    # `detached()` will attempt to touch the logfile to confirm that error
+    # messages won't be lost after detaching stdout/err, but this means we need
+    # to pre-format it rather than relying on `setup_logging_subsystem()` like
+    # we can elsewhere.
+    logfile = node_format(logfile, hostname)
     with detached(logfile, pidfile, uid, gid, umask, workdir, fake,
                   after_forkers=False):
         try:
@@ -135,7 +141,7 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
               type=click.Path(),
               callback=lambda ctx, _, value: value or ctx.obj.app.conf.worker_state_db,
               help_group="Worker Options",
-              help="Path to the state database. The extension '.db' may be"
+              help="Path to the state database. The extension '.db' may be "
                    "appended to the filename.")
 @click.option('-l',
               '--loglevel',
@@ -268,6 +274,7 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
               cls=CeleryOption,
               help_group="Embedded Beat Options")
 @click.pass_context
+@handle_preload_options
 def worker(ctx, hostname=None, pool_cls=None, app=None, uid=None, gid=None,
            loglevel=None, logfile=None, pidfile=None, statedb=None,
            **kwargs):
